<?php
/**
 * Kewi functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package kewi
 */


/**
 * define theme info
 * @since 1.0.0
 * */
 
 if (is_child_theme()){
	$theme = wp_get_theme();
	$parent_theme = $theme->Template;
	$theme_info = wp_get_theme($parent_theme);
}else{
	$theme_info = wp_get_theme();
}

define('KEWI_DEV_MODE',true);
$kewi_version = KEWI_DEV_MODE ? time() : $theme_info->get('Version');
define('KEWI_NAME',$theme_info->get('Name'));
define('KEWI_VERSION',$kewi_version);
define('KEWI_AUTHOR',$theme_info->get('Author'));
define('KEWI_AUTHOR_URI',$theme_info->get('AuthorURI'));


/**
 * Define Const for theme Dir
 * @since 1.0.0
 * */

define('KEWI_THEME_URI', get_template_directory_uri());
define('KEWI_IMG', KEWI_THEME_URI . '/assets/images');
define('KEWI_CSS', KEWI_THEME_URI . '/assets/css');
define('KEWI_JS', KEWI_THEME_URI . '/assets/js');
define('KEWI_THEME_DIR', get_template_directory());
define('KEWI_IMG_DIR', KEWI_THEME_DIR . '/assets/images');
define('KEWI_CSS_DIR', KEWI_THEME_DIR . '/assets/css');
define('KEWI_JS_DIR', KEWI_THEME_DIR . '/assets/js');
define('KEWI_INC', KEWI_THEME_DIR . '/inc');
define('KEWI_THEME_OPTIONS',KEWI_INC .'/theme-options');
define('KEWI_THEME_OPTIONS_IMG',KEWI_THEME_OPTIONS .'/img');

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
*/
	 
function kewi_setup(){
	
	// make the theme available for translation
	load_theme_textdomain( 'kewi', get_template_directory() . '/languages' );
	
	// add support for post formats
    add_theme_support('post-formats', [
        'standard', 'image', 'video', 'audio','gallery'
    ]);

    // add support for automatic feed links
    add_theme_support('automatic-feed-links');

    // let WordPress manage the document title
    add_theme_support('title-tag');
	
	// add editor style theme support
	function kewi_theme_add_editor_styles() {
		add_editor_style( 'custom-style.css' );
	}
	add_action( 'admin_init', 'kewi_theme_add_editor_styles' );

    // add support for post thumbnails
    add_theme_support('post-thumbnails');
	
	// hard crop center center
    set_post_thumbnail_size(1140, 850, ['center', 'center']);
	add_image_size( 'kewi-box-slider-small', 96, 96, true );
	
	
	// register navigation menus
    register_nav_menus(
        [
            'primary' => esc_html__('Primary Menu', 'kewi'),
            'footermenu' => esc_html__('Footer Menu', 'kewi'),
            'footermenutwo' => esc_html__('Footer Menu for Footer Template 2', 'kewi'),
        ]
    );
	
	
	// HTML5 markup support for search form, comment form, and comments
    add_theme_support('html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ));
	
	
	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 150,
		'width'       => 300,
		'flex-width'  => true,
		'flex-height' => true,
	) );
	
	
	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	
	/*
     * Enable support for wide alignment class for Gutenberg blocks.
     */
    add_theme_support( 'align-wide' );
    add_theme_support( 'editor-styles' );
    add_theme_support( 'wp-block-styles' );
		
}

add_action('after_setup_theme', 'kewi_setup');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
*/
 
function kewi_widget_init() {
	

        register_sidebar( array (
			'name' => esc_html__('Blog widget area', 'kewi'),
			'id' => 'sidebar-1',
			'description' => esc_html__('Blog Sidebar Widget.', 'kewi'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
			
		) );
		
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area One', 'kewi' ),
			'id'            => 'footer-widget-1',
			'description'   => esc_html__( 'Add Footer  widgets here.', 'kewi' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Two', 'kewi' ),
			'id'            => 'footer-widget-2',
			'description'   => esc_html__( 'Add Footer widgets here.', 'kewi' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Three', 'kewi' ),
			'id'            => 'footer-widget-3',
			'description'   => esc_html__( 'Add Footer widgets here.', 'kewi' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Four', 'kewi' ),
			'id'            => 'footer-widget-4',
			'description'   => esc_html__( 'Add Footer widgets here.', 'kewi' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Template 2 Left Widget', 'kewi' ),
			'id'            => 'footer-widget-two-left',
			'description'   => esc_html__( 'Add Footer widgets here.', 'kewi' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Header Canvas Menu Widget', 'kewi' ),
			'id'            => 'header-one-nav-wid',
			'description'   => esc_html__( 'Add Header widgets here.', 'kewi' ),
			'before_widget' => '<div id="%1$s" class="header-panel-nav-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );



					
}

add_action('widgets_init', 'kewi_widget_init');


/**
 * Enqueue scripts and styles.
 */
function kewi_scripts() {
	
	// Theme CSS 
	
	wp_enqueue_style( 'font-awesomes', KEWI_CSS . '/font-awesome.css');
	wp_enqueue_style( 'icon-font',  KEWI_CSS . '/icon-font.css' );
	wp_enqueue_style( 'remix-font',  KEWI_CSS . '/remixicon.css' );
	wp_enqueue_style( 'animate',  KEWI_CSS . '/animate.css' );
	wp_enqueue_style( 'flaticon',  KEWI_CSS . '/flaticon.css' );
	wp_enqueue_style( 'magnific-popup',  KEWI_CSS . '/magnific-popup.css' );
	wp_enqueue_style( 'owl-carousel',  KEWI_CSS . '/owl.carousel.min.css' );
	wp_enqueue_style( 'swipe-slider',  KEWI_CSS . '/swipe-slider.css' );
	wp_enqueue_style( 'owl-theme',  KEWI_CSS . '/owl.theme.min.css' );
	wp_enqueue_style( 'slick',  KEWI_CSS . '/slick.css' );
	wp_enqueue_style( 'slicknav',  KEWI_CSS . '/slicknav.css' );
	wp_enqueue_style( 'bootstrap', KEWI_CSS . '/bootstrap.min.css', array(), '5.2.0', 'all');
	wp_enqueue_style( 'odometer',  KEWI_CSS . '/odometer.css' );
	wp_enqueue_style( 'kewi-fonts', KEWI_CSS . '/theme-fonts.css', array(), '1.0', 'all');
	wp_enqueue_style( 'kewi-main',  KEWI_CSS . '/main.css' );
	wp_enqueue_style( 'kewi-responsive',  KEWI_CSS . '/responsive.css' );	

	wp_enqueue_style( 'kewi-style', get_stylesheet_uri() );
	
	// Theme JS
	
	wp_enqueue_script( 'popper',  KEWI_JS . '/popper.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'bootstrap',  KEWI_JS . '/bootstrap.min.js', array( 'jquery' ),  '5.2.0', true );
	wp_enqueue_script( 'jquery-magnific-popup',  KEWI_JS . '/jquery.magnific-popup.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'owl-carousel',  KEWI_JS . '/owl.carousel.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'slick', KEWI_JS . '/slick.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'swipe-slide', KEWI_JS . '/swipe-slider.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-slicknav', KEWI_JS . '/jquery.slicknav.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-odometer', KEWI_JS . '/jquery.odometer.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-jarallax', KEWI_JS . '/jarallax.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-jarallax-video', KEWI_JS . '/jarallax-video.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'isotopejs',  KEWI_JS . '/jquery-isotope.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-appear',  KEWI_JS . '/jquery.appear.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-waypoints',  KEWI_JS . '/jquery.waypoints.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-easypiechart', KEWI_JS . '/jquery.easypiechart.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-imagesloaded', KEWI_JS . '/imagesloaded.pkgd.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-sticky-kit', KEWI_JS . '/Sticky-kit.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-scroll-trigger', KEWI_JS . '/ScrollTrigger.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-charming', KEWI_JS . '/charming.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-tweenmax', KEWI_JS . '/TweenMax.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-inview', KEWI_JS . '/jquery.inview.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-wow', KEWI_JS . '/wow.min.js', array( 'jquery' ), '1.0', true );
	


	// Custom JS Scripts
	
	wp_enqueue_script( 'kewi-scripts',  KEWI_JS . '/scripts.js', array( 'jquery' ),  '1.0', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	

}

add_action( 'wp_enqueue_scripts', 'kewi_scripts' );


/*
* Include codester helper functions
* @since 1.0.0
*/

if ( file_exists( KEWI_INC.'/cs-framework-functions.php' ) ) {
	require_once  KEWI_INC.'/cs-framework-functions.php';
}

if ( file_exists( KEWI_THEME_OPTIONS.'/theme-metabox.php' ) ) {
	require_once  KEWI_THEME_OPTIONS.'/theme-metabox.php';
}

if ( file_exists( KEWI_THEME_OPTIONS.'/theme-nav-options.php' ) ) {
	require_once  KEWI_THEME_OPTIONS.'/theme-nav-options.php';
}

if ( file_exists( KEWI_THEME_OPTIONS.'/theme-customizer.php' ) ) {
	require_once  KEWI_THEME_OPTIONS.'/theme-customizer.php';
}


if ( file_exists( KEWI_THEME_OPTIONS.'/theme-inline-styles.php' ) ) {
	require_once  KEWI_THEME_OPTIONS.'/theme-inline-styles.php';
}


/**
 * Required plugin installer 
*/
require get_template_directory() . '/inc/required-plugins.php';


/**
 * Custom template tags & functions for this theme.
*/
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';


/**
 * Nav walker class for this theme.
*/
require get_template_directory() . '/inc/theme-nav-walker.php';


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
*/
function kewi_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'kewi_content_width', 640 );
}

add_action( 'after_setup_theme', 'kewi_content_width', 0 );

/**
 * Nav menu fallback function
*/

function kewi_fallback_menu() {
	get_template_part( 'template-parts/default', 'menu' );
}

/**
 * Custom admin CSS hook
*/

function kewi_admin_style() {
  wp_enqueue_style( 'kewi-admin-style',  KEWI_CSS . '/admin-style.css' );
}

add_action( 'admin_enqueue_scripts', 'kewi_admin_style');

function kewi_enable_svg_upload( $upload_mimes ) {
    $upload_mimes['svg'] = 'image/svg+xml';
    $upload_mimes['svgz'] = 'image/svg+xml';
    return $upload_mimes;
}

add_filter( 'upload_mimes', 'kewi_enable_svg_upload', 10, 1 );