<?php
/*
 * Theme Customize Options
 * @package kewi
 * @since 1.0.0
 * */

if (!defined('ABSPATH'))
{
    exit(); // exit if access directly
    
}

if (class_exists('CSF'))
{

    $prefix = 'kewi';

    CSF::createCustomizeOptions($prefix . '_customize_options');

    // Create a top-tab
    CSF::createSection($prefix . '_customize_options', array(
        'id' => 'theme_settings', // Set a unique slug-like ID
        'title' => 'Kewi Options',
        'priority' => 10,
        'icon' => 'fa fa-heart',
    ));

    /*-------------------------------------
     ** General Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('General', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 15,
        'fields' => array(

        array(
            'type' => 'subheading',
            'content' => '<h3>' . esc_html__('Site Logo', 'kewi') . '</h3>',
        ) ,
            
        array(
            'id' => 'theme_logo',
            'title' => esc_html__('Main Logo','kewi'),
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Static Logo Image on Header Static', 'kewi')
        ), 
        
        array(
            'id' => 'theme_logo_transparent',
            'title' => esc_html__('Light or Transparent Logo', 'kewi') ,
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Transparent Logo Image', 'kewi')
        ) ,

        
        array(
            'id' => 'logo_width',
            'type' => 'slider',
            'title' => esc_html__('Set Logo Width','kewi'),
            'min' => 0,
            'max' => 300,
            'step' => 1,
            'unit' => 'px',
            'default' => 179,
            'desc' => esc_html__('Set Logo Width in px. Default Width 179px.', 'kewi') ,
            //'output' => '.header-style-one .logo.theme-logo img',
            'output_mode' => 'width',
        ) ,
        
        array(
            'id' => 'logo_width_light',
            'type' => 'slider',
            'title' => esc_html__('Set Transparent Logo Width','kewi'),
            'min' => 0,
            'max' => 300,
            'step' => 1,
            'unit' => 'px',
            'default' => 280,
            'desc' => esc_html__('Set Logo Width in px. Default Width 280px.', 'kewi') ,
            //'output' => '.transparent-header .logo.theme-logo img',
            'output_mode' => 'width',
        ) ,

        array(
            'id' => 'theme_logo3',
            'title' => esc_html__('Main Logo Header 3','kewi'),
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Static Logo Image on Header Static', 'kewi')
        ), 

      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Preloader','kewi').'</h3>'
      ),
      
      
      array(
        'id' => 'preloader_enable',
        'title' => esc_html__('Enable Preloader','kewi'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Preloader', 'kewi') ,
        'default' => true,
      ),
      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Back Top Options','kewi').'</h3>'
      ),
      
      
      array(
        'id' => 'back_top_enable',
        'title' => esc_html__('Scroll Top Button','kewi'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable scroll button', 'kewi') ,
        'default' => true,
      ),




        )

    ));

    /*-------------------------------------
     ** Header Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Header', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 11,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Header Layout', 'kewi') . '</h3>'
            ) ,

            array(
                'id' => 'nav_menu',
                'type' => 'image_select',
                'title' => esc_html__('Select Header Layout', 'kewi') ,
                'options' => array(
                    'nav-style-one' => KEWI_IMG . '/admin/header-style/style1.png',
                    'nav-style-two' => KEWI_IMG . '/admin/header-style/style2.png',
                    'nav-style-three' => KEWI_IMG . '/admin/header-style/style3.png',
                ) ,
                'default' => 'nav-style-one'
            ) ,

            array(
                    'id' => 'theme_header_sticky',
                    'title' => esc_html__('Sticky Header', 'kewi') ,
                    'type' => 'switcher',
                    'desc' => esc_html__('Enable Sticky Header', 'kewi') ,
                    'default' => true,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Header Components', 'kewi') . '</h3>'
            ) ,


            array(
                'id' => 'search_bar_enable',
                'title' => esc_html__('Search Box','kewi'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Search Box', 'kewi') ,
                'default' => true,
            ),

            array(
                'id' => 'burger_nav_enable',
                'title' => esc_html__('Right Burger Menu','kewi'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Burger Menu', 'kewi') ,
                'default' => true,
            ),


            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Set Social Network', 'kewi') . '</h3>'
            ) ,

            array(
                'id' => 'header_social_enable',
                'title' => esc_html__('Show Header Social Icons', 'kewi') ,
                'type' => 'switcher',
                'desc' => esc_html__('Enable Header Social Icons', 'kewi') ,
                'default' => true,
            ) ,

            array(
                'id' => 'header-social-icon',
                'type' => 'repeater',
                'title' => 'Add New Social',
                'fields' => array(

                    array(
                        'id' => 'icon',
                        'type' => 'icon',
                        'title' => esc_html__('Pick Up Your Social Icon', 'kewi') ,
                    ) ,

                    array(
                        'id' => 'link',
                        'type' => 'text',
                        'title' => esc_html__('Enter Social Url', 'kewi') ,
                    ) ,

                    array(
                        'id' => 'text',
                        'type' => 'text',
                        'title' => esc_html__('Enter Social Platform Name', 'kewi') ,
                    ) ,



                ) ,
            ) ,

        )

    ));

    /*-------------------------------------
     ** Color Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Colors', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 12,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Choose Theme Color', 'kewi') . '</h3>',
            ) ,

            array(
                'id' => 'theme_main_color',
                'type' => 'color',
                'title' => esc_html__('Primary Color', 'kewi') ,
                'default' => '#222222',
            ) ,


            array(
                'id' => 'theme_body_bg',
                'type' => 'color',
                'title' => esc_html__('Body Background Color', 'kewi') ,
                'default' => '#ffffff',
                'output'      => 'body',
                'output_mode' => 'background-color'
            ) ,


            array(
                'id' => 'theme_body_text',
                'type' => 'color',
                'title' => esc_html__('Body Text Color', 'kewi') ,
                'default' => '#777777',
                'output'      => 'body',
                'output_mode' => 'color'
            ) ,

            array(
                'id' => 'theme_footer_bg',
                'type' => 'color',
                'title' => esc_html__('Footer Background Color', 'kewi') ,
                'default' => '#222222',
                'output'      => '.footer-area',
                'output_mode' => 'background-color'
            ) ,



        )

    ));




    /*-------------------------------------
     ** Typography Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Typography', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 14,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Body', 'kewi') . '</h3>'
            ) ,

            array(
                'id' => 'body-typography',
                'type' => 'typography',
                'output' => 'body',
                'default' => array(
                    'font-family' => 'Space Grotesk',
                    'font-weight' => '400',
                    'font-size' => '18',
                    'line-height' => '26',
                    'letter-spacing' => '0',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                ) ,

            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading', 'kewi') . '</h3>'
            ) ,

            array(
                'id' => 'heading-one-typo',
                'type' => 'typography',

                'output' => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ),
                
                'default' => array(
                    'color' => '#000',
                    'font-family' => 'Space Grotesk',
                    'font-weight' => '600',
                    'subset' => 'latin-ext',
                    'text-align' => 'inherit',
                    'font-size' => false,
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,


        )
    ));

    /*-------------------------------------
     **Blog Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Blog: Listing', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 15,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Blog Options', 'kewi') . '</h3>'
            ) ,

            array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => 'Blog Page Title',
                'default' => 'Blog Page',
                'desc' => 'Type Blog Page Title',
            ) ,

            array(
                'id' => 'page-spacing-blog',
                'type' => 'spacing',
                'title' => 'Blog Page Spacing',
                'output' => '.main-container.blog-spacing',
                'output_mode' => 'padding', // or margin, relative
                'default' => array(
                    'top' => '80',
                    'right' => '0',
                    'bottom' => '80',
                    'left' => '0',
                    'unit' => 'px',
                ) ,
            ) ,

            array(
                'id' => 'blog_breadcrumb_enable',
                'title' => esc_html__('Breadcrumb', 'kewi') ,
                'type' => 'switcher',
                'desc' => esc_html__('Enable Breadcrumb', 'kewi') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_thumb',
                'title' => esc_html__('Show Post Image', 'kewi') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog Image', 'kewi') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_cat',
                'title' => esc_html__('Show Catgeories', 'kewi') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog category', 'kewi') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_date',
                'title' => esc_html__('Show Date', 'kewi') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog date', 'kewi') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_excerpt',
                'title' => esc_html__('Show Excerpt', 'kewi') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Post Excerpt', 'kewi') ,
                'default' => true,
            ) ,

            array(
                'id' => 'set_blog_excerpt_limit',
                'type' => 'text',
                'title' => 'Post Excerpt Length',
                'default' => 32,
                'desc' => 'Set Blog Page Excerpt Length',
            ) ,

        )
    ));

    /*-------------------------------------
     **Category Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Category: Listing', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 16,
        'fields' => array(


        array(
            'id' => 'cat_breadcrumb_enable',
            'title' => esc_html__('Breadcrumb', 'kewi') ,
            'type' => 'switcher',
            'desc' => esc_html__('Enable Breadcrumb', 'kewi') ,
            'default' => true,
        ) ,

        array(
        'id' => 'page-spacing-category',
        'type' => 'spacing',
        'title' => esc_html__('Category Page Spacing','kewi'),
        'output' => '.main-container.cat-page-spacing',
        'output_mode' => 'padding', // or margin, relative
        'default' => array(
            'top' => '75',
            'right' => '0',
            'bottom' => '75',
            'left' => '0',
            'unit' => 'px',
        ) ,
        ) ,

        array(
            'id' => 'cat_page_categroy',
            'title' => esc_html__('Show Catgeories', 'kewi') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Blog category', 'kewi') ,
            'default' => true,
        ) ,


        )
    ));

    /*-------------------------------------
     **Single Blog Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Blog: Single Post', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 17,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Theme Blog Post Options. You can Customize Each Post by Editing Individually.', 'kewi') . '</h3>'
            ) ,

      
       array(
            'id' => 'kewi_single_blog_layout',
            'type' => 'image_select',
            'title' => esc_html__('Select Single Blog Style','kewi'),
            'options' => array(
                'single-one' => KEWI_IMG . '/admin/page/blog-1.png',
                'single-two' => KEWI_IMG . '/admin/page/blog-2.png',
            ),
            'default' => 'single-one'
        ),
        
        array(
            'id' => 'post-spacing-single',
            'type' => 'spacing',
            'title' => esc_html__('Single Blog Spacing','kewi'),
            'output' => '.single-one-bwrap',
            'output_mode' => 'padding', // or margin, relative
            'default' => array(
                'top' => '85',
                'right' => '0',
                'bottom' => '40',
                'left' => '0',
                'unit' => 'px',
            ) ,
        ) ,
        
        array(
            'id' => 'show_blog_details_thumb',
            'title' => esc_html__('Post Featured Image', 'kewi') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Blog Featured Image', 'kewi') ,
            'default' => true,
        ) ,
    
        array(
            'id' => 'blog_single_cat',
            'title' => esc_html__('Post Catgeory','kewi'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Category Meta','kewi'),
            'default' => true,
        ),
        
        array(
            'id' => 'blog_single_author',
            'title' => esc_html__('Post Author','kewi'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Author Meta','kewi'),
            'default' => true,
        ),

        array(
            'id' => 'blog_single_date',
            'title' => esc_html__('Post Date', 'kewi') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Date Meta', 'kewi') ,
            'default' => true,
        ) ,

        array(
            'id' => 'blog_social',
            'title' => esc_html__('Social Share Box','kewi'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Social Share Box','kewi'),
            'default' => false,
        ),

        array(
            'id' => 'blog_tags',
            'title' => esc_html__('Show Tags','kewi'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Post Tags','kewi'),
            'default' => false,
        ),

        array(
            'id' => 'blog_author_box',
            'title' => esc_html__('Author Box','kewi'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Post Author Box','kewi'),
            'default' => false,
        ),


        array(
            'id' => 'blog_nav',
            'title' => esc_html__('Show Navigation','kewi'),
            'type' => 'switcher',
            'desc' => esc_html__('Post Navigation','kewi'),
            'default' => true,
        ),

        array(
            'id'         => 'blog_prev_title',
            'type'       => 'text',
            'title'      => esc_html__('Previous Post Text','kewi'),
            'default'    => esc_html__('Previous Post','kewi'),
            'desc'       => esc_html__('Type Previous Post Link Title','kewi'),
        ),
        
        array(
            'id'         => 'blog_next_title',
            'type'       => 'text',
            'title'      => esc_html__('Next Post Text','kewi'),
            'default'    => esc_html__('Next Post','kewi'),
            'desc'       => esc_html__('Type Next Post Link Title','kewi'),
        ),
        
        
        array(
            'id' => 'blog_related',
            'title' => esc_html__('Show Related Posts','kewi'),
            'type' => 'switcher',
            'desc' => esc_html__('Related Posts','kewi'),
            'default' => false,
        ),    


        )
    ));

    /*-------------------------------------
     ** Error Page Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Error Page', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 18,
        'fields' => array(

            array( //nav bar one start
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('404 Options', 'kewi') . '</h3>'
            ) ,

            array(
                'id' => 'error_title',
                'type' => 'text',
                'title' => 'Error Page Title',
                'default' => 'OOPS THAT PAGE CANT BE FOUND',
            ) ,

            array(
                'id' => 'error_btn_text',
                'type' => 'text',
                'title' => 'Error Page Button Text',
                'default' => 'Go To Homepage',
            ) ,

            array(
                'id' => 'page-spacing-error',
                'type' => 'spacing',
                'title' => 'Page Spacing',
                'output' => 'body.error404 .main-container',
                'output_mode' => 'padding', // or margin, relative
                'default' => array(
                    'top' => '75',
                    'right' => '0',
                    'bottom' => '75',
                    'left' => '0',
                    'unit' => 'px',
                ) ,
            ) ,

        )
    ));


	
    /*-------------------------------------
     ** Footer Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Footer Settings', 'kewi') ,
        'parent' => 'theme_settings',
        'priority' => 21,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Layout 2 Options', 'kewi') . '</h3>'
            ) ,
            

            array(
                'id' => 'copyright_text',
                'title' => esc_html__('Footer Copyright Text', 'kewi') ,
                'type' => 'textarea',
            ) ,

            array(
                'id' => 'footer_social_enable',
                'title' => esc_html__('Do You want to Show Footer Social Icons', 'kewi') ,
                'type' => 'switcher',
                'default' => false,
            ) ,

            array(
                'id' => 'footer-social-icon',
                'type' => 'repeater',
                'title' => 'Repeater',
                'fields' => array(
                    array(
                        'id' => 'link',
                        'type' => 'text',
                        'title' => esc_html__('Inter Social Url', 'kewi') ,
                    ) ,

                    array(
                        'id' => 'text',
                        'type' => 'text',
                        'title' => esc_html__('Inter Social Platform Name', 'kewi') ,
                    ) ,

                ) ,
            ) ,
        )
    ));




}

