<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package kewi
 */

$blog_title = kewi_get_customize_option('blog_title');
$blog_breadcrumb = kewi_get_customize_option('blog_breadcrumb_enable', true);

get_header();

?>

	<?php if($blog_breadcrumb == true) :?>

	<section class="breadcrumb-area breadcrumb-bg" data-background="<?php echo KEWI_IMG.'/breadcrumb_bg.jpg'; ?>">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-lg-6">
                    <div class="breadcrumb-content">
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb">
                                <li class="breadcrumb-item"><a href="<?php echo esc_url(home_url('/')); ?>"><?php esc_html_e('Home', 'kewi'); ?></a></li>
                                <li class="breadcrumb-item active" aria-current="page"><?php esc_html_e('Blog', 'kewi'); ?></li>
                            </ol>
                        </nav>
                        <h2 class="title"><?php if(!empty($blog_title)) { echo esc_html($blog_title); } else { echo esc_html_e('Blog Page', 'kewi');}?></h2>
                    </div>
                </div>
            </div>
        </div>
    </section>

	<?php endif; ?>

	
	<section id="main-content" class="blog main-container blog-spacing" role="main">
		<div class="container">
			<div class="row">
				<div class="<?php if(is_active_sidebar('sidebar-1')) { echo "col-lg-8"; } else { echo "col-lg-12";}?> col-md-12">
					<div class="category-layout-two main-blog-layout blog-new-layout theme-layout-mainn">
					<?php if (have_posts()): ?>
					
						<div class="main-content-inner category-layout-one <?php if(has_post_thumbnail()) { echo "has-fblog"; } else { echo "no-fblog"; } ?>">
						<?php while (have_posts()): the_post(); ?>
							<?php get_template_part('template-parts/content', get_post_format());?>
						<?php
						endwhile; ?>
						</div>	
						
						<div class="theme-pagination-style">
							<?php
								the_posts_pagination(array(
								'next_text' => '<i class="ri-arrow-right-line"></i>',
								'prev_text' => '<i class="ri-arrow-left-line"></i>',
								'screen_reader_text' => ' ',
								'type'               => 'list'
							));
							?>
						</div>
						
						<?php else: ?>
							<?php get_template_part('template-parts/content', 'none'); ?>
						<?php endif; ?>
						
					</div>
				</div>

				<?php get_sidebar(); ?>

			</div>
		</div>
	</section>
	
	<?php get_footer(); ?>
